ghoauth
=======

|travis|_ |coveralls|_ |pypibadge|_

-----
About
-----
This is an OAuth 2.0 provider implementation in Python 3 developed at `Gehirn Inc`_.

-------
Install
-------

.. code:: shell

  $ pip install ghoauth

Or

.. code:: shell

  $ python setup.py install

-------
License
-------
ghoauth is licensed under the Apache License Version 2.0.  See ./LICENSE.rst.


.. _Gehirn Inc: http://www.gehirn.co.jp/

.. _travis: https://travis-ci.org/GehirnInc/ghoauth
.. |travis| image:: https://travis-ci.org/GehirnInc/ghoauth.svg?branch=master

.. _coveralls: https://coveralls.io/r/GehirnInc/ghoauth?branch=master
.. |coveralls| image:: https://coveralls.io/repos/GehirnInc/ghoauth/badge.png?branch=master

.. _pypibadge: http://badge.fury.io/py/ghoauth
.. |pypibadge| image:: https://badge.fury.io/py/ghoauth.svg?dummy
